@@ -1,4 +1,4 @@
-from tealprint import TealLevel
+from tealprint import TealConfig, TealLevel
 
 from .utils.config_file_args import Backups, ConfigFileArgs, Email, General, Mysql
 
@@ -9,21 +9,21 @@ class Config:
     def __init__(self) -> None:
         # Default values
         self.app_name: str = _app_name
-        self.level: TealLevel = TealLevel.info
         self.force_full: bool = False
         self.general = General()
         self.backups = Backups()
         self.mysql = Mysql()
         self.email = Email()
+        TealConfig.level = TealLevel.info
 
     def set_from_cli(self, args) -> None:
         """Set additional configuration from script arguments"""
         self.force_full = args.full_backup
 
         if args.debug:
-            self.level = TealLevel.debug
+            TealConfig.level = TealLevel.debug
         elif args.verbose:
-            self.level = TealLevel.verbose
+            TealConfig.level = TealLevel.verbose
 
     def set_from_config_file(self, args: ConfigFileArgs) -> None:
         self.general = args.general
